==> ejc-signaturemanage-impl-3.0.1-20220608.071458-164-sources.jar: com/ejianc/business/signaturemanage/controller/SignatureRectController.java <==
package com.ejianc.business.signaturemanage.controller;

import com.ejianc.business.signaturemanage.service.ISignatureRectService;
import com.ejianc.business.signaturemanage.vo.SignatureVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

/**
 * @author baipengyan
 * @date 2022/6/1
 * @description 签章定位
 */
@Validated
@RestController
@RequestMapping(value = "/signatureRect")
public class SignatureRectController {

	private final Logger logger = LoggerFactory.getLogger(this.getClass());

	private final ISignatureRectService service;

	public SignatureRectController(ISignatureRectService service) {
		this.service = service;
	}


	/**
	 * 签章定位：逻辑删除签章合同数据
	 */
	@PostMapping(value = "/deleteSignatureRect")
	public void deleteSignatureRect() {
		logger.info("签章定位：逻辑删除签章合同数据");
	}

	/**
	 * 签章定位：获取预签署链接
	 */
	@PostMapping(value = "/fetchPreSignUrl")
	public CommonResponse<String> fetchPreSignUrl(@Valid @RequestBody SignatureVO signatureVO) {
		return CommonResponse.success("获取预签署链接，请求成功！", service.fetchPreSignUrl(signatureVO));
	}

	/**
	 * 签章定位：发起签章
	 */
	@GetMapping(value = "/sendSignature")
	public CommonResponse<String> sendSignature(@NotNull(message = "PM系统合同id不能为空！") @RequestParam(value = "contractId") Long contractId) {
		service.sendSignature(contractId);
		return CommonResponse.success("当前合同id：" + contractId + "，发起签章成功！");
	}

}

==> ejc-signaturemanage-impl-3.0.1-20220618.082411-181-sources.jar: com/ejianc/business/signaturemanage/controller/SignatureRectController.java <==
package com.ejianc.business.signaturemanage.controller;

import com.ejianc.business.signaturemanage.service.ISignatureRectService;
import com.ejianc.business.signaturemanage.vo.SignatureVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

/**
 * @author baipengyan
 * @date 2022/6/1
 * @description 签章定位
 */
@Validated
@RestController
@RequestMapping(value = "/signatureRect")
public class SignatureRectController {

	private final Logger logger = LoggerFactory.getLogger(this.getClass());

	private final ISignatureRectService service;

	public SignatureRectController(ISignatureRectService service) {
		this.service = service;
	}


	/**
	 * 签章定位：逻辑删除签章合同数据
	 */
	@GetMapping(value = "/deleteSignatureRect")
	public CommonResponse<String> deleteSignatureRect(@NotNull(message = "PM系统合同id不能为空！") @RequestParam(value = "contractId") Long contractId) {
		service.deleteSignatureRect(contractId);
		return CommonResponse.success("删除签章合同数据成功");
	}

	/**
	 * 签章定位：获取预签署链接
	 */
	@PostMapping(value = "/fetchPreSignUrl")
	public CommonResponse<String> fetchPreSignUrl(@Valid @RequestBody SignatureVO signatureVO) {
		return CommonResponse.success("获取预签署链接，请求成功！", service.fetchPreSignUrl(signatureVO));
	}

	/**
	 * 签章定位：发起签章
	 */
	@GetMapping(value = "/sendSignature")
	public CommonResponse<String> sendSignature(@NotNull(message = "PM系统合同id不能为空！") @RequestParam(value = "contractId") Long contractId) {
		service.sendSignature(contractId);
		return CommonResponse.success("当前合同id：" + contractId + "，发起签章成功！");
	}

}
